ete2.phylo.spoverlap

Package ete2 :: Package phylo :: Module spoverlap |
[hide private]
[frames] | no frames]

# Module spoverlap

source code

Functions | [hide private]
get_evol_events_from_leaf(node, sos_thr=0.0) Returns a list of duplication and speciation events in which the current node has been involved. | source code
get_evol_events_from_root(node, sos_thr) Returns a list of **all** duplication and speciation events detected after this node. | source code

Variables | [hide private]
| __VERSION__ = ``'``ete2-2.0rev95``'``
| __package__ = ``'``ete2.phylo``'``

Function Details | [hide private]

### get_evol_events_from_leaf(node, sos_thr=0.0) | source code
Returns a list of duplication and speciation events in which the current node has been involved. Scanned nodes are also labeled internally as dup=True|False. You can access this labels using the 'node.dup' sintaxis. Method: the algorithm scans all nodes from the given leafName to the root. Nodes are assumed to be duplications when a species overlap is found between its child linages. Method is described more detail in: "The Human Phylome." Huerta-Cepas J, Dopazo H, Dopazo J, Gabaldon T. Genome Biol. 2007;8(6):R109.

### get_evol_events_from_root(node, sos_thr) | source code
Returns a list of **all** duplication and speciation events detected after this node. Nodes are assumed to be duplications when a species overlap is found between its child linages. Method is described more detail in: "The Human Phylome." Huerta-Cepas J, Dopazo H, Dopazo J, Gabaldon T. Genome Biol. 2007;8(6):R109.